@@ -358,7 +358,7 @@ define({
 	'javascriptFormatting' : 'Javascript Formatting',
 	'js_indent_size' : 'Indention size:',
 	'js_indent_char' : 'Indentation character:',
-	'js_eol' : 'Charater(s) to use as line terminators:',
+	'js_eol' : 'Character(s) to use as line terminators:',
 	'js_end_with_newline' : 'End ouput with newline:',
 	'indentation_unix' : 'Unix',
 	'indentation_mac' : 'Mac',
@@ -385,7 +385,7 @@ define({
 	'keep_array_indentation' : 'Preserve array indentation:',
 	'space_before_conditional' : 'Space before condition:',
 	'unescape_strings' : 'Decode printable characters encoded in xNN notation:',
-	'js_wrap_line_length' : 'Wrap lines at next opportunity after N characters: (0 for unlimited)',
+	'js_wrap_line_length' : 'Wrap lines at next opportunity after N characters (0 for unlimited):',
 	'e4x' : 'Pass E4X xml literal through untouched:',
 	'comma_first' : 'Put commas at the beginning of new line instead of end:',
 	'operator_position' : 'Position for operator:',
